/*
   Module with *Messages functions, based on code from Red Hat Linux installer
   Copyright (C) 1998 Pawel Gajda (mis@k2.net.pl)
   
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
*/

/*
 * Copyright 1999 Red Hat Software 
 *
 * This software may be freely redistributed under the terms of the GNU
 * public license.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

/*
   $Id: scrmsgs.c,v 1.1 2001/02/05 15:51:05 malekith Exp $
*/

#include <stdio.h>
#include <stdlib.h>
#include <stdarg.h>
#include <string.h>
#include <unistd.h>
#include <newt.h>

#include <defines.h>

static void display_messge(const char *title, const char *btext,
                           const char *fmt, va_list p)
{
    newtWinMessagev((char*)title, btext != NULL ? (char*)btext : _("Dismiss"),
                    (char*)fmt, p);
}

void debugMessage(const char *fmt, ...)
{
    va_list p;
    va_start(p, fmt);
    display_messge("** DEBUG message **", NULL, fmt, p);
    va_end(p);
}

void errorMessage(const char *fmt, ...)
{
    va_list p;
    va_start(p, fmt);
    display_messge(_("Error"), NULL, fmt, p);
    va_end(p);
}

void warnMessage(const char *fmt, ...)
{
    va_list p;
    va_start(p, fmt);
    display_messge(_("Warning"), NULL, fmt, p);
    va_end(p);
}

void normMessage(const char *title, const char *fmt, ...)
{
    va_list p;
    va_start(p, fmt);
    display_messge(title ? title : _("Message"), _("OK"), fmt, p);
    va_end(p);
}


void statusMessage(char *title, const char *fmt, ...) {
    newtComponent t, f;

    char *buf = NULL;
    int width, height;
    int size = 0;
    int i = 0;
    va_list args;

    va_start(args, fmt);

    do {
	size += 1000;
	if (buf) free(buf);
	buf = malloc(size);
	i = vsnprintf(buf, size, fmt, args);
    } while (i == size);

    va_end(args);
    
    /* calculate width && height */
    width = strlen(buf)+3;
    height = 3 + (width/60);
    
    if(width > 60)
        width = 60;

    if(title == NULL)
        title = _("Wait");
    
    newtCenteredWindow(width, height, title);

    t = newtTextbox(1, 1, width - 2, height - 2, NEWT_TEXTBOX_WRAP);
    newtTextboxSetText(t, buf);
    f = newtForm(NULL, NULL, 0);

    free(buf);

    newtFormAddComponent(f, t);

    newtDrawForm(f);
    newtRefresh();
    newtFormDestroy(f);
}

void destroy_statusMessage(void)
{
    newtPopWindow();
}


int questionMessage(const char *title, const char *question)
{
    while(1) {
        int rc = newtWinChoice(title ? (char*)title : "?", _("Yes"),_("No"),
                                (char*)question); 
        
        if(rc == 0)
            
            newtWinMessage("Warning","OK","Don't abort me!");
        
        else if(rc == 2) /* No */
            return 0;
        
        else 
            return 1;
    }
}
